{pkgs', ...}: let
  bashFktScript = import ./bash-fkt.nix {
    inherit pkgs';
  };

  updateChangelogScript = import ./update-changelog.nix {
    inherit pkgs';
  };
in
  pkgs'.writeShellScriptBin "release" ''

    source ${pkgs'.common}/bin/common
    ${bashFktScript}

    echo_header "Release "

    if [ -z "$CI_REPOSITORY_URL" ]; then
        echo_fail "Error: CI_REPOSITORY_URL environment variable is not set."
        exit 1
    fi

    if [ -z "$CI_PROJECT_DIR" ]; then
        echo_fail "Error: CI_PROJECT_DIR environment variable is not set."
        exit 1
    fi

    cd $CI_PROJECT_DIR || exit 1

    echo_step "Set git remote url to https://pad:secret@''${CI_REPOSITORY_URL#*@}"
    ${pkgs'.git}/bin/git remote set-url origin https://pad:''${GITLAB_TOKEN}@''${CI_REPOSITORY_URL#*@}

    ${pkgs'.git}/bin/git fetch --all --tags --unshallow
    ${pkgs'.git}/bin/git reset --hard origin/master
    ${pkgs'.git}/bin/git clean -fd
    ${pkgs'.git}/bin/git checkout $CI_COMMIT_REF_NAME
    ${pkgs'.git}/bin/git pull origin $CI_COMMIT_REF_NAME

    if ! ${pkgs'.git}/bin/git --no-pager log --decorate=short --pretty=oneline -n 10
    then
        echo_fail "Error: Could not get git log."
        exit 1
    fi

    ${pkgs'.git}/bin/git fetch --prune --prune-tags

    echo_step "Bumping version"
    gitVersion=$(${pkgs'.version}/bin/version predict --exit-code-if-no-bump)
    if [ -z "$gitVersion" ]; then
        echo_ok "There is no version bump."
        echo_ok "done"
        exit 0
    fi

    echo_step "Write project version"
    ### marker

    export VERSION=$gitVersion
    export COMMIT="$CI_COMMIT_SHA"
    export NAME=$(basename $(pwd) | sed 's/./\U&/' | sed 's/-//g')
    export MNEMONIC=$(echo $NAME | tr '[:upper:]' '[:lower:]' | sed 's/[^a-z0-9]//g')
    ${pkgs'.envsubst}/bin/envsubst < ./nix/config/release.nix.template > ./nix/config/release.nix

    if ! ${pkgs'.projectNodeJS}/bin/npm version "$gitVersion" --no-git-tag-version --allow-same-version 2>/dev/null; then
        echo_fail "Error: Could not write project version."
        exit 1
    fi

    if ${pkgs'.git}/bin/git tag -l | grep -q "$gitVersion"; then
        echo_step "Tag $gitVersion existiert bereits. Lösche und setze den Tag neu."
        ${pkgs'.git}/bin/git tag -d "$gitVersion"
        ${pkgs'.git}/bin/git push --push-option=ci.skip origin --delete "$gitVersion"
    fi

    ${pkgs'.git}/bin/git tag -a "$gitVersion" -m"chore: bump version to $gitVersion"
    ${updateChangelogScript}/bin/update-changelog
    cd $CI_PROJECT_DIR || exit 1

    if ! ${pkgs'.git}/bin/git tag -d "$gitVersion" 2>/dev/null; then
      echo_fail "Error: Could not delete git tag $gitVersion."
      exit 1
    fi

    ${pkgs'.git}/bin/git commit -m "chore: release $gitVersion" CHANGELOG.md ./nix/config/release.nix package.json

    ${pkgs'.git}/bin/git tag -a "$gitVersion" -m"chore: bump version to $gitVersion"
    ${pkgs'.git}/bin/git --no-pager log --decorate=short --pretty=oneline -n 5

    if ! ${pkgs'.git}/bin/git push --push-option=ci.variable="DEPLOY_VERSION=$gitVersion" origin "$CI_COMMIT_REF_NAME" --tags ; then
        echo_fail "Error: Could not push git tag $gitVersion."
        exit 1
    fi

    echo_ok "done"
  ''
